@@ -1,6 +1,6 @@
 from django.contrib import admin
 from checklists.admin import ChecklistAnswerInline
-from actions.models import Checkup, Maintenance, Fix, Report, PAction, Action
+from actions.models import Checkup, Maintenance, Fix, Report
 from actions.forms import ReportAdminForm
 from libs.admin import LinkedInline
 from files.admin import UploadInline
@@ -33,9 +33,9 @@ admin.site.register(Report, ReportAdmin)
 
 
 
-
-class ActionInline(LinkedInline):
-    model = Action
+#
+#class ActionInline(LinkedInline):
+#    model = Action
 
 
 class ReportInline(LinkedInline):
